import { Context, TextMapGetter, TextMapPropagator, TextMapSetter } from '@opentelemetry/api';
export declare const UBER_TRACE_ID_HEADER = "uber-trace-id";
export declare const UBER_BAGGAGE_HEADER_PREFIX = "uberctx";
/**
 * Propagates {@link SpanContext} through Trace Context format propagation.
 * {trace-id}:{span-id}:{parent-span-id}:{flags}
 * {trace-id}
 * 64-bit or 128-bit random number in base16 format.
 * Can be variable length, shorter values are 0-padded on the left.
 * Value of 0 is invalid.
 * {span-id}
 * 64-bit random number in base16 format.
 * {parent-span-id}
 * Set to 0 because this field is deprecated.
 * {flags}
 * One byte bitmap, as two hex digits.
 * Inspired by jaeger-client-node project.
 */
export declare class JaegerPropagator implements TextMapPropagator {
    private readonly _jaegerTraceHeader;
    /**
     * @param {string} [customTraceHeader="uber-trace-id"] - HTTP header to inject\extract trace from.
     **/
    constructor(customTraceHeader?: string);
    inject(context: Context, carrier: unknown, setter: TextMapSetter): void;
    extract(context: Context, carrier: unknown, getter: TextMapGetter): Context;
    fields(): string[];
}
//# sourceMappingURL=JaegerPropagator.d.ts.map